@@ -19,15 +19,20 @@ import os
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
+import inspect
+import textwrap
 from .common import TEMPORARY_PATCHES, torch_compile
 from .utils import (
     patch_function,
     KWARGS_TYPE,
     raise_error,
     logger,
+    Cache,
 )
+from ..hf_utils import dtype_from_config
 torch_cuda_device = torch.cuda.device
 
+
 @torch_compile(dynamic = True, fullgraph = True)
 def swiglu_torch_forward(a, alpha, limit, dtype = None):
     a_gelu = a[..., ::2].to(torch.float32)
@@ -184,7 +189,11 @@ def patch_gpt_oss():
 
         @staticmethod
         def backward(ctx, grad_token):
-            raise NotImplementedError("Backwards pass using MXFP4 is still under construction!")
+            raise NotImplementedError(
+                "Backwards pass using MXFP4 is still under construction!\n"\
+                "Instead, use `unsloth/gpt-oss-20b-BF16` for bfloat16 training which will work for LoRA.\n"\
+                "Or, use `load_in_4bit = True` which allows finetuning."
+            )
             (pre_act, gamma, gather_src, gather_dst, scatter_src, scatter_dst,) = ctx.saved_tensors
             self_class = ctx.self_class
             limit = self_class.limit
@@ -427,7 +436,7 @@ class GptOssExperts(nn.Module):
         self.expert_dim = config.intermediate_size
         self.alpha = 1.702
         self.limit = getattr(config, "swiglu_limit", 7.0)
-        self.dtype = config.torch_dtype
+        self.dtype = dtype_from_config(config)
 
         self.gate_up_projs = nn.ModuleList([
             nn.Linear(self.hidden_size, 2 * self.expert_dim, dtype=self.dtype)
@@ -450,13 +459,15 @@ class GptOssExperts(nn.Module):
         num_experts = routing_weights.shape[1]
         if self.training:
             next_states = torch.zeros_like(hidden_states, dtype=torch.float32, device=hidden_states.device)
-            with torch.no_grad():
-                expert_mask = torch.nn.functional.one_hot(router_indices, num_classes=num_experts)
-                expert_mask = expert_mask.permute(2, 1, 0)
-                expert_hitted = torch.greater(expert_mask.sum(dim=(-1, -2)), 0).nonzero()
-            for expert_idx in expert_hitted[:]:
+            # with torch.no_grad():
+                # expert_mask = torch.nn.functional.one_hot(router_indices, num_classes=num_experts)
+                # expert_mask = expert_mask.permute(2, 1, 0)
+                # expert_hitted = torch.greater(expert_mask.sum(dim=(-1, -2)), 0).nonzero()
+            # for expert_idx in expert_hitted[:]:
+            for expert_idx in range(num_experts):
                 with torch.no_grad():
-                    _, token_idx = torch.where(expert_mask[expert_idx[0]])
+                    # _, token_idx = torch.where(expert_mask[expert_idx[0]])
+                    token_idx, _ = torch.where(router_indices == expert_idx)
                 current_state = hidden_states[token_idx]
                 gate_up = self.gate_up_projs[expert_idx](current_state)
                 gated_output = swiglu_torch_forward(gate_up, self.alpha, self.limit)
@@ -469,7 +480,7 @@ class GptOssExperts(nn.Module):
                 weighted_output = out * routing_weights[token_idx, expert_idx, None].to(torch.float32)
                 next_states.index_add_(0, token_idx, weighted_output)
             next_states = next_states.view(batch_size, -1, self.hidden_size)
-            return next_states
+            return next_states.to(hidden_states.dtype)
         else:
             X_rep = hidden_states.unsqueeze(0).expand(num_experts, -1, -1)
             gate_up_list = [up_l(X_rep[e]) for e, up_l in enumerate(self.gate_up_projs)]
@@ -494,15 +505,16 @@ class GptOssTopKRouter(nn.Module):
         self.top_k = config.num_experts_per_tok
         self.num_experts = config.num_local_experts
         self.hidden_dim = config.hidden_size
-        self.linear = nn.Linear(self.hidden_dim, self.num_experts, dtype=config.torch_dtype)
+        self.linear = nn.Linear(self.hidden_dim, self.num_experts, dtype=dtype_from_config(config))
 
     @torch_compile(dynamic = True, fullgraph = True)
     def forward(self, hidden_states):
         hidden_states = hidden_states.reshape(-1, self.hidden_dim)
         router_logits = self.linear(hidden_states.to(self.linear.weight.dtype))  # (batch_size * seq_len, num_experts)
         router_top_value, router_indices = torch.topk(router_logits, self.top_k, dim=-1)  # (seq_len, top_k)
-        router_top_value = torch.nn.functional.softmax(router_top_value, dim=1, dtype=torch.float32).to(router_top_value.dtype)
-        router_scores = torch.zeros_like(router_logits).scatter_(1, router_indices, router_top_value)
+        dtype = torch.float32 if router_logits.dtype == torch.float16 else router_logits.dtype
+        router_top_value = torch.nn.functional.softmax(router_top_value, dim=1, dtype=torch.float32).to(dtype)
+        router_scores = torch.zeros_like(router_logits, dtype = dtype).scatter_(1, router_indices, router_top_value)
         return router_scores, router_indices
 pass
 
@@ -540,20 +552,19 @@ def patch_gpt_oss_linearized():
             num_experts = routing_weights.shape[1]
             if self.training:
                 next_states = torch.zeros_like(hidden_states, dtype=torch.float32, device=hidden_states.device)
-                with torch.no_grad():
-                    expert_mask = torch.nn.functional.one_hot(router_indices, num_classes=num_experts)
-                    expert_mask = expert_mask.permute(2, 1, 0)
-                    expert_hitted = torch.greater(expert_mask.sum(dim=(-1, -2)), 0).nonzero()
-                has_float32 = False
-                for expert_idx in expert_hitted[:]:
+                # with torch.no_grad():
+                #     expert_mask = torch.nn.functional.one_hot(router_indices, num_classes=num_experts)
+                #     expert_mask = expert_mask.permute(2, 1, 0)
+                #     expert_hitted = torch.greater(expert_mask.sum(dim=(-1, -2)), 0).nonzero()
+                # for expert_idx in expert_hitted[:]:
+                for expert_idx in range(num_experts):
                     with torch.no_grad():
-                        _, token_idx = torch.where(expert_mask[expert_idx[0]])
+                        # _, token_idx = torch.where(expert_mask[expert_idx[0]])
+                        token_idx, _ = torch.where(router_indices == expert_idx)
                     current_state = hidden_states[token_idx]
                     gate_up = self.gate_up_projs[expert_idx](current_state)
                     down_proj = self.down_projs[expert_idx]
-                    dtype = getattr(down_proj, "compute_dtype", torch.float16)
-                    if dtype == torch.float32: has_float32 = True
-                    gated_output = swiglu_torch_forward(gate_up, self.alpha, self.limit, dtype = dtype)
+                    gated_output = swiglu_torch_forward(gate_up, self.alpha, self.limit, dtype = torch.float32)
                     # gate, up = gate_up[..., ::2], gate_up[..., 1::2]
                     # gate = gate.clamp(min=None, max=self.limit)
                     # up = up.clamp(min=-self.limit, max=self.limit)
@@ -561,14 +572,14 @@ def patch_gpt_oss_linearized():
                     # gated_output = (up + 1) * glu
 
                     # Force float32 matrix multiply on some down projection modules
-                    gated_output = gated_output.to(dtype)
+                    gated_output = gated_output.to(torch.float32)
                     device_type = gated_output.device.type if isinstance(gated_output.device.type, str) and gated_output.device.type != "mps" else "cpu"
                     with torch.autocast(device_type=device_type, enabled=False): # Force float32
                         out = down_proj(gated_output)
                     weighted_output = out.to(torch.float32) * routing_weights[token_idx, expert_idx, None].to(torch.float32)
                     next_states.index_add_(0, token_idx, weighted_output)
                 next_states = next_states.view(batch_size, -1, self.hidden_size)
-                return next_states.to(torch.float32 if has_float32 else torch.float16)
+                return next_states.to(torch.float32)
             else:
                 X_rep = hidden_states.unsqueeze(0).expand(num_experts, -1, -1)
                 gate_up_list = [up_l(X_rep[e]) for e, up_l in enumerate(self.gate_up_projs)]
@@ -585,9 +596,7 @@ def patch_gpt_oss_linearized():
                 device_type = fused.device.type if isinstance(fused.device.type, str) and fused.device.type != "mps" else "cpu"
                 with torch.autocast(device_type=device_type, enabled=False): # Force float32
                     out_list = [
-                        down_l(fused[e].to(
-                            getattr(down_l, "compute_dtype", torch.float16)
-                        ))
+                        down_l(fused[e].to(torch.float32))
                         for e, down_l in enumerate(self.down_projs)
                     ]
                 outs = torch.stack(out_list, dim=0)
@@ -607,6 +616,133 @@ pass
 TEMPORARY_PATCHES.append(patch_gpt_oss_linearized)
 
 
+def patch_GptOssAttention():
+    if os.environ.get("UNSLOTH_ENABLE_FLEX_ATTENTION", "1") == "0": return
+    try:
+        from ..flex_attention import flex_attention_with_sink
+        assert flex_attention_with_sink is not None
+    except Exception as e:
+        return raise_error("flex_attention_with_sink", e)
+    try:
+        import transformers.models.gpt_oss.modeling_gpt_oss
+        transformers.models.gpt_oss.modeling_gpt_oss.GptOssAttention
+        from transformers.models.gpt_oss.modeling_gpt_oss import apply_rotary_pos_emb, repeat_kv
+    except Exception as e:
+        return raise_error("transformers.models.gpt_oss.modeling_gpt_oss.GptOssAttention", e)
+    
+    def eager_attention_forward(
+        module: nn.Module,
+        query: torch.Tensor,
+        key: torch.Tensor,
+        value: torch.Tensor,
+        attention_mask: Optional[torch.Tensor],
+        scaling: float,
+        dropout: float = 0.0,
+        **kwargs,
+    ):
+        key_states = repeat_kv(key, module.num_key_value_groups)
+        value_states = repeat_kv(value, module.num_key_value_groups)
+        attn_weights = torch.matmul(query, key_states.transpose(2, 3)) * scaling
+        if attention_mask is not None:
+            causal_mask = attention_mask[:, :, :, : key_states.shape[-2]]
+            attn_weights = attn_weights + causal_mask
+
+        sinks = module.sinks.reshape(1, -1, 1, 1).expand(query.shape[0], -1, query.shape[-2], -1)
+        combined_logits = torch.cat([attn_weights, sinks], dim=-1)
+
+        # This was not in the original implementation and slightly affect results; it prevents overflow in BF16/FP16
+        # when training with bsz>1 we clamp max values.
+        # combined_logits = combined_logits - combined_logits.max(dim=-1, keepdim=True).values
+        probs = torch.nn.functional.softmax(combined_logits, dim=-1, dtype=torch.float32).to(combined_logits.dtype)
+        scores = probs[..., :-1]  # we drop the sink here
+        attn_weights = nn.functional.dropout(scores, p=dropout, training=module.training)
+        attn_output = torch.matmul(attn_weights, value_states)
+        attn_output = attn_output.transpose(1, 2).contiguous()
+        return attn_output, attn_weights
+    pass
+
+    apply_rotary_pos_emb = torch_compile(apply_rotary_pos_emb)
+    eager_attention_forward = torch_compile(eager_attention_forward)
+    def forward_function(
+        self,
+        hidden_states: torch.Tensor,
+        position_embeddings: tuple[torch.Tensor, torch.Tensor],
+        attention_mask: Optional[torch.Tensor],
+        past_key_value: Optional[Cache] = None,
+        cache_position: Optional[torch.LongTensor] = None,
+        **kwargs: KWARGS_TYPE,
+    ) -> tuple[torch.Tensor, torch.Tensor]:
+        input_shape = hidden_states.shape[:-1]
+        hidden_shape = (*input_shape, -1, self.head_dim)
+        query_states = self.q_proj(hidden_states).view(hidden_shape).transpose(1, 2)
+        key_states   = self.k_proj(hidden_states).view(hidden_shape).transpose(1, 2)
+        value_states = self.v_proj(hidden_states).view(hidden_shape).transpose(1, 2)
+        cos, sin = position_embeddings
+        query_states, key_states = apply_rotary_pos_emb(query_states, key_states, cos, sin)
+
+        if past_key_value is not None:
+            cache_kwargs = {"cache_position": cache_position}
+            key_states, value_states = past_key_value.update(key_states, value_states, self.layer_idx, cache_kwargs)
+
+        if self.training:
+            attn_output = flex_attention_with_sink(
+                self,
+                query_states,
+                key_states,
+                value_states,
+            )
+            attn_weights = None
+        else:
+            # Weirdly for inference, flex attention returns gibberish
+            # Most likely due to left padding
+            attn_output, attn_weights = eager_attention_forward(
+                self,
+                query_states,
+                key_states,
+                value_states,
+                attention_mask,
+                dropout=0.0 if not self.training else self.attention_dropout,
+                scaling=self.scaling,
+                sliding_window=self.sliding_window,
+                s_aux=self.sinks,  # diff with Llama
+                **kwargs,
+            )
+        attn_output = attn_output.reshape(*input_shape, -1).contiguous()
+        attn_output = self.o_proj(attn_output)
+        return attn_output, attn_weights
+    pass
+
+    def forward(
+        self,
+        hidden_states: torch.Tensor,
+        position_embeddings: tuple[torch.Tensor, torch.Tensor],
+        attention_mask: Optional[torch.Tensor],
+        past_key_value: Optional[Cache] = None,
+        cache_position: Optional[torch.LongTensor] = None,
+        **kwargs: KWARGS_TYPE,
+    ) -> tuple[torch.Tensor, Optional[torch.Tensor], Optional[tuple[torch.Tensor]]]:
+        return forward_function(self, hidden_states, position_embeddings, attention_mask, past_key_value, cache_position, **kwargs)
+    patch_function(transformers.models.gpt_oss.modeling_gpt_oss.GptOssAttention, "forward", forward)
+
+    # Change past_key_value to past_key_values
+    def forward(
+        self,
+        hidden_states: torch.Tensor,
+        position_embeddings: tuple[torch.Tensor, torch.Tensor],
+        attention_mask: Optional[torch.Tensor],
+        past_key_values: Optional[Cache] = None,
+        cache_position: Optional[torch.LongTensor] = None,
+        **kwargs: KWARGS_TYPE,
+    ) -> tuple[torch.Tensor, Optional[torch.Tensor], Optional[tuple[torch.Tensor]]]:
+        return forward_function(self, hidden_states, position_embeddings, attention_mask, past_key_values, cache_position, **kwargs)
+    patch_function(transformers.models.gpt_oss.modeling_gpt_oss.GptOssAttention, "forward", forward)
+
+    # Set env variable for padding purposes
+    os.environ["UNSLOTH_ENABLE_FLEX_ATTENTION"] = "1"
+pass
+TEMPORARY_PATCHES.append(patch_GptOssAttention)
+
+
 try:
     from openai_harmony import (
         Author,
@@ -711,3 +847,229 @@ def encode_conversations_with_harmony(
     harmony_decoded_text = encoding.decode(harmony_input_ids)
     return harmony_decoded_text, harmony_input_ids
 pass
+
+
+# Fix https://github.com/huggingface/transformers/pull/40474
+# RuntimeError: Unsloth: Failed to load model. Both AutoConfig and PeftConfig loading failed.
+# AutoConfig error: 'GptOssConfig' object has no attribute 'max_position_embeddings'
+try:
+    from transformers.configuration_utils import PretrainedConfig, layer_type_validation
+    from transformers.modeling_rope_utils import rope_config_validation
+
+    class Old_GptOssConfig(PretrainedConfig):
+        r"""
+        This will yield a configuration to that of the BERT
+        [google-bert/bert-base-uncased](https://huggingface.co/google-bert/bert-base-uncased) architecture.
+
+        """
+
+        model_type = "gpt_oss"
+        base_model_pp_plan = {
+            "embed_tokens": (["input_ids"], ["inputs_embeds"]),
+            "layers": (["hidden_states", "attention_mask"], ["hidden_states"]),
+            "norm": (["hidden_states"], ["hidden_states"]),
+        }
+        base_model_tp_plan = {
+            "layers.*.self_attn.q_proj": "colwise",
+            "layers.*.self_attn.k_proj": "colwise",
+            "layers.*.self_attn.v_proj": "colwise",
+            "layers.*.self_attn.o_proj": "rowwise",
+            "layers.*.self_attn.sinks": "local_rowwise",
+            "layers.*.mlp.experts": "gather",
+            "layers.*.mlp.router": "ep_router",
+            "layers.*.mlp.experts.gate_up_proj": "grouped_gemm",
+            "layers.*.mlp.experts.gate_up_proj_bias": "grouped_gemm",
+            "layers.*.mlp.experts.down_proj": "grouped_gemm",
+            "layers.*.mlp.experts.down_proj_bias": "grouped_gemm",
+        }
+
+        def __init__(
+            self,
+            num_hidden_layers: int = 36,
+            num_local_experts: int = 128,
+            vocab_size: int = 201088,
+            hidden_size: int = 2880,
+            intermediate_size: int = 2880,
+            head_dim: int = 64,
+            num_attention_heads: int = 64,
+            num_key_value_heads: int = 8,
+            sliding_window: int = 128,
+            rope_theta: float = 150000.0,
+            tie_word_embeddings=False,
+            hidden_act: str = "silu",
+            initializer_range: float = 0.02,
+            max_position_embeddings=131072,
+            rms_norm_eps: float = 1e-5,
+            rope_scaling={"rope_type": "yarn", "factor": 32.0, "beta_fast": 32.0, "beta_slow": 1.0, "truncate": False},
+            attention_dropout: float = 0.0,
+            num_experts_per_tok=4,
+            router_aux_loss_coef: float = 0.9,
+            output_router_logits=False,
+            use_cache=True,
+            layer_types=None,
+            **kwargs,
+        ):
+            self.vocab_size = vocab_size
+            self.hidden_size = hidden_size
+            self.intermediate_size = intermediate_size
+            self.num_hidden_layers = num_hidden_layers
+            self.num_attention_heads = num_attention_heads
+            self.num_local_experts = num_local_experts
+            self.sliding_window = sliding_window
+            self.num_experts_per_tok = num_experts_per_tok
+            # for backward compatibility
+            if num_key_value_heads is None:
+                num_key_value_heads = num_attention_heads
+
+            self.num_key_value_heads = num_key_value_heads
+            self.hidden_act = hidden_act
+            self.initializer_range = initializer_range
+            self.rms_norm_eps = rms_norm_eps
+            self.rope_theta = rope_theta
+            self.rope_scaling = rope_scaling
+            self.attention_dropout = attention_dropout
+            self.head_dim = head_dim if head_dim is not None else self.hidden_size // self.num_attention_heads
+            self.layer_types = layer_types
+            if self.layer_types is None:
+                self.layer_types = [
+                    "sliding_attention" if bool((i + 1) % 2) else "full_attention" for i in range(self.num_hidden_layers)
+                ]
+            layer_type_validation(self.layer_types)
+
+            # Validate the correctness of rotary position embeddings parameters
+            # BC: if there is a 'type' field, copy it it to 'rope_type'.
+            if self.rope_scaling is not None and "type" in self.rope_scaling:
+                self.rope_scaling["rope_type"] = self.rope_scaling["type"]
+            rope_config_validation(self)
+
+            self.attention_bias = True
+            self.max_position_embeddings = max_position_embeddings
+            self.router_aux_loss_coef = router_aux_loss_coef
+            self.output_router_logits = output_router_logits
+            self.use_cache = use_cache
+            super().__init__(
+                tie_word_embeddings=tie_word_embeddings,
+                **kwargs,
+            )
+
+    class GptOssConfig(PretrainedConfig):
+        r"""
+        This will yield a configuration to that of the BERT
+        [google-bert/bert-base-uncased](https://huggingface.co/google-bert/bert-base-uncased) architecture.
+
+        """
+
+        model_type = "gpt_oss"
+        base_model_pp_plan = {
+            "embed_tokens": (["input_ids"], ["inputs_embeds"]),
+            "layers": (["hidden_states", "attention_mask"], ["hidden_states"]),
+            "norm": (["hidden_states"], ["hidden_states"]),
+        }
+        base_model_tp_plan = {
+            "layers.*.self_attn.q_proj": "colwise",
+            "layers.*.self_attn.k_proj": "colwise",
+            "layers.*.self_attn.v_proj": "colwise",
+            "layers.*.self_attn.o_proj": "rowwise",
+            "layers.*.self_attn.sinks": "local_rowwise",
+            "layers.*.mlp.experts": "gather",
+            "layers.*.mlp.router": "ep_router",
+            "layers.*.mlp.experts.gate_up_proj": "grouped_gemm",
+            "layers.*.mlp.experts.gate_up_proj_bias": "grouped_gemm",
+            "layers.*.mlp.experts.down_proj": "grouped_gemm",
+            "layers.*.mlp.experts.down_proj_bias": "grouped_gemm",
+        }
+
+        def __init__(
+            self,
+            num_hidden_layers: int = 36,
+            num_local_experts: int = 128,
+            vocab_size: int = 201088,
+            hidden_size: int = 2880,
+            intermediate_size: int = 2880,
+            head_dim: int = 64,
+            num_attention_heads: int = 64,
+            num_key_value_heads: int = 8,
+            sliding_window: int = 128,
+            rope_theta: float = 150000.0,
+            tie_word_embeddings=False,
+            hidden_act: str = "silu",
+            initializer_range: float = 0.02,
+            max_position_embeddings=131072,
+            rms_norm_eps: float = 1e-5,
+            rope_scaling={"rope_type": "yarn", "factor": 32.0, "beta_fast": 32.0, "beta_slow": 1.0, "truncate": False},
+            attention_dropout: float = 0.0,
+            num_experts_per_tok=4,
+            router_aux_loss_coef: float = 0.9,
+            output_router_logits=False,
+            use_cache=True,
+            layer_types=None,
+            **kwargs,
+        ):
+            self.vocab_size = vocab_size
+            self.hidden_size = hidden_size
+            self.intermediate_size = intermediate_size
+            self.num_hidden_layers = num_hidden_layers
+            self.num_attention_heads = num_attention_heads
+            self.num_local_experts = num_local_experts
+            self.sliding_window = sliding_window
+            self.num_experts_per_tok = num_experts_per_tok
+            # for backward compatibility
+            if num_key_value_heads is None:
+                num_key_value_heads = num_attention_heads
+
+            self.num_key_value_heads = num_key_value_heads
+            self.hidden_act = hidden_act
+            self.initializer_range = initializer_range
+            self.rms_norm_eps = rms_norm_eps
+            self.rope_theta = rope_theta
+            self.rope_scaling = rope_scaling
+            self.attention_dropout = attention_dropout
+            self.head_dim = head_dim if head_dim is not None else self.hidden_size // self.num_attention_heads
+            self.layer_types = layer_types
+            if self.layer_types is None:
+                self.layer_types = [
+                    "sliding_attention" if bool((i + 1) % 2) else "full_attention" for i in range(self.num_hidden_layers)
+                ]
+            layer_type_validation(self.layer_types)
+            self.attention_bias = True
+            self.max_position_embeddings = max_position_embeddings
+            self.router_aux_loss_coef = router_aux_loss_coef
+            self.output_router_logits = output_router_logits
+            self.use_cache = use_cache
+
+            # Validate the correctness of rotary position embeddings parameters
+            # BC: if there is a 'type' field, copy it it to 'rope_type'.
+            if self.rope_scaling is not None and "type" in self.rope_scaling:
+                self.rope_scaling["rope_type"] = self.rope_scaling["type"]
+            rope_config_validation(self)
+
+            self.attention_bias = True
+            self.max_position_embeddings = max_position_embeddings
+            self.router_aux_loss_coef = router_aux_loss_coef
+            self.output_router_logits = output_router_logits
+            self.use_cache = use_cache
+            super().__init__(
+                tie_word_embeddings=tie_word_embeddings,
+                **kwargs,
+            )
+
+    def patch_gpt_oss_config():
+        try:
+            import transformers.models.gpt_oss.configuration_gpt_oss
+            transformers.models.gpt_oss.configuration_gpt_oss.GptOssConfig
+        except Exception as e:
+            return raise_error("transformers.models.gpt_oss.configuration_gpt_oss", e)
+
+        try:
+            current_class = textwrap.dedent(inspect.getsource(transformers.models.gpt_oss.configuration_gpt_oss.GptOssConfig))
+            new_class = textwrap.dedent(inspect.getsource(Old_GptOssConfig))
+            new_class = new_class.replace("Old_GptOssConfig", "GptOssConfig")
+            if new_class == current_class:
+                logger.info("Unsloth: Updating GPT OSS Config to fix missing `max_position_embeddings`")
+                patch_function(transformers.models.gpt_oss.configuration_gpt_oss, "GptOssConfig", GptOssConfig)
+        except Exception as e:
+            return raise_error("transformers.models.gpt_oss.configuration_gpt_oss", e)
+    pass
+    TEMPORARY_PATCHES.append(patch_gpt_oss_config)
+except Exception as e:
+    raise_error("transformers.models.gpt_oss.configuration_gpt_oss.GptOssConfig", e)
