@@ -20,10 +20,14 @@ __all__ = [
     "is_main_process",
     "is_distributed",
     "distributed_function",
+    "torch_distributed_get_rank",
 ]
 
 from packaging.version import Version as TrueVersion
 import torch
+import os
+import time
+import contextlib
 
 def Version(version):
     # All Unsloth Zoo code licensed under LGPLv3
@@ -60,27 +64,49 @@ def _get_dtype(dtype):
 pass
 
 
-def is_main_process():
-    is_initialized = torch.distributed.is_initialized()
-    return (not is_initialized) or (is_initialized and torch.distributed.get_rank() == 0)
-pass
+import functools
+torch_distributed_is_initialized = torch.distributed.is_initialized
+torch_distributed_is_torchelastic_launched = torch.distributed.is_torchelastic_launched
+torch_distributed_get_rank = torch.distributed.get_rank
 
+def is_main_process():
+    if torch_distributed_is_initialized():
+        # torch.distributed.init_process_group was run, so get_rank works
+        return torch_distributed_get_rank() == 0
+    elif torch_distributed_is_torchelastic_launched():
+        # accelerate launch for example calls init_process_group later
+        return os.environ.get("RANK", "0") == "0"
+    return True
+pass
 
 def is_distributed():
-    return torch.distributed.is_initialized()
+    return torch_distributed_is_initialized() or torch_distributed_is_torchelastic_launched()
 pass
 
-
 def distributed_function(n = 1, function = None, *args, **kwargs):
-    if torch.distributed.is_initialized():
-        if torch.distributed.get_rank() == 0:
+    if is_distributed():
+        if is_main_process():
             object_list = function(*args, **kwargs)
             if n == 1: object_list = [object_list]
         else:
             object_list = [None for _ in range(n)]
         # broadcast_object_list auto blocks so no need for barrier
-        torch.distributed.broadcast_object_list(object_list, src = 0, device = "cpu")
-        if n == 1: result = object_list[0]
+        if not torch_distributed_is_initialized():
+            # But check if the function even works!
+            # This happens when torch_distributed_is_torchelastic_launched()==True but
+            # torch_distributed_is_initialized()==False
+            # Trick is to just add a 0.01+0.01*RANK second sleep and print with flush
+            time.sleep(0.01 + 0.01*int(os.environ.get("RANK", "0")))
+            with contextlib.redirect_stdout(None):
+                print("", flush = True)
+            object_list = function(*args, **kwargs)
+            if n == 1: object_list = [object_list]
+        else:
+            torch.distributed.broadcast_object_list(object_list, src = 0)
+        if n == 1:
+            result = object_list[0]
+        else:
+            result = object_list
     else:
         result = function(*args, **kwargs)
     return result
